@@ -13,19 +13,7 @@ from typing import Tuple
 
 import anyio
 from asyncscope import Scope, main_scope, scope
-
-from .codec import packer, stream_unpacker
-from .default import CFG
-from .exceptions import (
-    CancelledError,
-    ClientAuthMethodError,
-    ClientAuthRequiredError,
-    ServerClosedError,
-    ServerConnectionError,
-    ServerError,
-    error_types,
-)
-from .util import (
+from moat.util import (
     DelayedRead,
     DelayedWrite,
     NotGiven,
@@ -40,6 +28,18 @@ from .util import (
     num2byte,
 )
 
+from .codec import packer, stream_unpacker
+from .default import CFG
+from .exceptions import (
+    CancelledError,
+    ClientAuthMethodError,
+    ClientAuthRequiredError,
+    ServerClosedError,
+    ServerConnectionError,
+    ServerError,
+    error_types,
+)
+
 logger = logging.getLogger(__name__)
 
 ClosedResourceError = anyio.ClosedResourceError
@@ -460,7 +460,7 @@ class Client:
     async def dh_secret(self, length=1024):
         """Exchange a diffie-hellman secret with the server"""
         if self._dh_key is None:
-            from diffiehellman.diffiehellman import DiffieHellman
+            from moat.lib.diffiehellman import DiffieHellman
 
             def gen_key():
                 k = DiffieHellman(key_length=length, group=(5 if length < 32 else 14))
