@@ -3,9 +3,9 @@
 import sys
 
 import asyncclick as click
+from moat.util import P, Path, yprint
 
 from distkv.data import data_get
-from distkv.util import P, Path, yprint
 
 ACL = set("rwdcxena")
 # read, write, delete, create, access, enumerate
