@@ -3,8 +3,7 @@
 import sys
 
 import asyncclick as click
-
-from distkv.util import (
+from moat.util import (
     NotGiven,
     P,
     Path,
@@ -112,7 +111,7 @@ async def set_(obj, thread, script, data, vars_, eval_, path_, async_, info):
         vs = set()
     vd = msg.setdefault("default", {})
 
-    vd = process_args(vd, vars_, eval_, path_, vs)
+    vd = process_args(vd, vars_, eval_, path_, vs=vs)
     msg["vars"] = list(vs)
     msg["default"] = vd
 
