@@ -3,10 +3,10 @@
 import sys
 
 import asyncclick as click
+from moat.util import P, Path, yprint
 
 from distkv.data import add_dates
 from distkv.errors import ErrorRoot
-from distkv.util import P, Path, yprint
 
 
 @click.group()  # pylint: disable=undefined-variable
