@@ -3,10 +3,9 @@
 from collections.abc import Mapping
 
 import asyncclick as click
+from moat.util import P, PathLongener, yprint
 from range_set import RangeSet
 
-from distkv.util import P, PathLongener, yprint
-
 
 @click.group(short_help="Control internal state.")  # pylint: disable=undefined-variable
 async def cli():
