@@ -2,7 +2,7 @@
 This module contains the default values for distkv configuration.
 """
 
-from .util import NotGiven, P, attrdict
+from moat.util import NotGiven, P, attrdict
 
 __all__ = ["PORT", "CFG"]
 
@@ -68,13 +68,16 @@ CFG = attrdict(
     ),
     server=attrdict(
         # server-side configuration
-        backend=NotGiven,  # must be specified
+        backend="mqtt",  # default
         buffer=10,  # per-stream buffer
         serf=attrdict(
             # how to connect to Serf
             host="localhost",
             port=7373,
         ),
+        mqtt=attrdict(
+            uri="mqtt://localhost:1883"
+        ),
         root=(":distkv",),  # event message name prefix. Should start with a colon.
         paranoia=False,  # typecheck server-to-server updates?
         # which addresses/ports to accept DistKV connections on
