@@ -11,11 +11,10 @@ from collections import defaultdict
 from logging import getLogger
 from typing import Any, List
 
-from distmqtt.utils import create_queue
+from moat.util import NotGiven, Path, attrdict, create_queue
 from range_set import RangeSet
 
 from .exceptions import ACLError
-from .util import NotGiven, Path, attrdict
 
 logger = getLogger(__name__)
 
