@@ -12,7 +12,17 @@ from weakref import ref
 import anyio
 import psutil
 from asyncactor import AuthPingEvent, NodeList, PingEvent, TagEvent, UntagEvent
-from distmqtt.utils import create_queue
+from moat.util import (
+    NotGiven,
+    P,
+    Path,
+    attrdict,
+    combine_dict,
+    digits,
+    logger_for,
+    create_queue,
+    spawn,
+)
 
 from .actor import (
     ActorState,
@@ -24,7 +34,6 @@ from .actor import (
 )
 from .exceptions import ServerError
 from .obj import AttrClientEntry, ClientRoot
-from .util import NotGiven, P, Path, attrdict, combine_dict, digits, logger_for, spawn
 
 try:
     ClosedResourceError = anyio.exceptions.ClosedResourceError
