@@ -2,10 +2,10 @@ import logging
 import weakref
 
 import jsonschema
+from moat.util import NotGiven, P, Path, make_proc, singleton
 
 from .exceptions import ACLError, ClientError
 from .model import Entry
-from .util import NotGiven, P, Path, make_proc, singleton
 
 logger = logging.getLogger(__name__)
 
