@@ -1,11 +1,11 @@
 import logging
 
 import pytest
+from moat.util import P
 
 from distkv.code import CodeRoot, ModuleRoot
 from distkv.errors import ErrorRoot
 from distkv.mock.mqtt import stdtest
-from distkv.util import P
 
 logger = logging.getLogger(__name__)
 
