@@ -2,11 +2,11 @@ import logging
 
 import pytest
 import trio
+from moat.util import P, PathLongener
 
 from distkv.auth import loader
 from distkv.client import ServerError
 from distkv.mock.mqtt import stdtest
-from distkv.util import P, PathLongener
 
 logger = logging.getLogger(__name__)
 
