@@ -1,9 +1,9 @@
 import pytest
 import trio
+from moat.util import P
 
 from distkv.exceptions import CancelledError
 from distkv.mock.serf import stdtest
-from distkv.util import P
 
 
 @pytest.mark.trio
